<?php 
namespace PortalPeople\paygate\controllers\api;
use yii\rest\Controller;
use Yii;
use PortalPeople\paygate\models\Payment;


class PaymentsController extends Controller
{
    public function actionPayment()
    {
        $request = Yii::$app->request;
        return Payment::paygatepay($request->get());
    }
    public function actionRequest()
    {
        $request = Yii::$app->request;
        return Payment::paygatecreate($request->get());
    }
}