<?php

namespace PortalPeople\paygate\assets;

use yii\web\AssetBundle;

/**
 * Settings Asset Bundle for PayGate module
 */
class SettingsAsset extends AssetBundle
{
    public $sourcePath = '@PortalPeople/paygate/assets';
    
    public $css = [
        'settings.css',
    ];
    
    public $js = [
        'settings.js',
    ];
    
    public $depends = [
        'yii\web\YiiAsset',
        'yii\bootstrap\BootstrapAsset',
        'yii\bootstrap\BootstrapPluginAsset',
    ];
}
