<?php 
namespace PortalPeople\paygate\models;
use backend\models\Cartsbe;
use Yii;
class Paygate extends \common\models\DynamicModel
{

    const sandboxUrl = 'https://sis-t.redsys.es:25443/sis/realizarPago';
    const productionUrl = 'https://sis.redsys.es/sis/rest/trataPeticionREST';
    public static function localAttributes()
    {
        return [
        ];
    }

}